@@ -1,7 +1,7 @@
 __author__ = 'Altertech, https://www.altertech.com/'
 __copyright__ = 'Copyright (C) 2020 Altertech'
 __license__ = 'MIT'
-__version__ = '0.0.14'
+__version__ = '0.0.15'
 
 # TODO: 2fa
 
@@ -515,7 +515,7 @@ def logout():
     if get_user_id():
         result = _call_handler('account.logout')
         _log_user_event('account.logout')
-        for i in ('id', 'picture', 'confirmed', 'confirmed_session'):
+        for i in ('id', 'picture', 'name', 'confirmed', 'confirmed_session'):
             try:
                 del session[f'{_d.x_prefix}user_{i}']
             except KeyError:
